# Changelog

<!--next-version-placeholder-->

## v1.4.1 (2022-07-16)
### Fix
* Markdown.util.etree is deprecated ([`8601c14`](https://github.com/Mara-Li/mdx_wikilink_plus/commit/8601c149959c151a7bca084a49af6434d84ac154))
